Nota
L'accés a aquesta pàgina requereix autorització. Podeu provar d'iniciar la sessió o de canviar els directoris.
L'accés a aquesta pàgina requereix autorització. Podeu provar de canviar els directoris.
En este artículo se documentan las operaciones de api REST de imagen, audio (voz) y generación de vídeo para Azure OpenAI en la versión preliminar v1. Para las finalizaciones de chat, incrustaciones, valoraciones, archivos, ajuste preciso, respuestas, almacenes de vectores y todas las demás operaciones, consulte la referencia oficial de la API REST de OpenAI Azure.
Inferencia del plano de datos
En el resto de este artículo se tratan las operaciones de imagen, audio y vídeo en la nueva versión preliminar de la API v1 de la especificación de inferencia del plano de datos de OpenAI Azure. Para más información, consulte la guía del ciclo de vida de la API.
Para obtener la API completa del plano de datos de disponibilidad general v1, consulte la referencia oficial de la API rest de OpenAI Azure.
Crear discurso
POST {endpoint}/openai/v1/audio/speech?api-version=preview
Genera audio de texto a voz a partir del texto de entrada.
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de Microsoft Foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Cuerpo de la solicitud
Tipo de contenido: varias partes/datos de formulario
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| input | string | Texto para el que se va a generar audio. La longitud máxima es de 4096 caracteres. | Sí | |
| instrucciones | string | Controle la voz del audio generado con instrucciones adicionales. No funciona con tts-1 o tts-1-hd. |
No | |
| model | string | Modelo que se va a usar para esta solicitud de texto a voz. | Sí | |
| formato_de_respuesta | object | Formatos de salida de audio admitidos para texto a voz. | No | |
| velocidad | número | Velocidad de voz para el audio generado. Los valores son válidos en el intervalo de 0,25 a 4,0, con 1,0 los valores predeterminados y superiores correspondientes a una voz más rápida. | No | 1 |
| stream_format | enum | Formato en el que se va a transmitir el audio. Los formatos admitidos son sse y audio.
sse no se admite para tts-1 o tts-1-hd.Valores posibles: sse, audio |
No | |
| voz | object | Sí |
Responses
Código de estado: 200
Descripción: la solicitud se ha realizado correctamente.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/octet-stream | string |
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureErrorResponse |
Examples
Example
Sintetiza el audio del texto proporcionado.
POST {endpoint}/openai/v1/audio/speech?api-version=preview
{
"input": "Hi! What are you going to make?",
"voice": "fable",
"response_format": "mp3",
"model": "tts-1"
}
Respuestas: Código de estado: 200
{
"body": "101010101"
}
Crear transcripción
POST {endpoint}/openai/v1/audio/transcriptions?api-version=preview
Transcribe el audio en el idioma de entrada.
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Cuerpo de la solicitud
Tipo de contenido: varias partes/datos de formulario
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| chunking_strategy | object | No | ||
| " prefix_padding_ms | entero | Cantidad de audio que se va a incluir antes de que el VAD detecte voz (en milisegundos). | No | 300 |
| └─ silencio_duración_ms | entero | Duración del silencio para detectar la detención de voz (en milisegundos). Con valores más cortos, el modelo responderá más rápidamente, pero puede saltar en pausas cortas del usuario. | No | 200 |
| └─ umbral | número | Umbral de confidencialidad (de 0,0 a 1,0) para la detección de actividad de voz. Un umbral superior requerirá audio más alto para activar el modelo y, por tanto, podría funcionar mejor en entornos ruidosos. | No | 0,5 |
| └─ Tipo | enum | Debe establecerse en server_vad para habilitar la fragmentación manual mediante VAD del lado servidor.Valores posibles: server_vad |
No | |
| archivo | string | Sí | ||
| filename | string | Nombre de archivo opcional o identificador descriptivo al que se va a asociar con los datos de audio. | No | |
| include[] | array | Información adicional que se va a incluir en la respuesta de transcripción.
logprobs devolverá las probabilidades de registro de los tokens en la respuesta para comprender la confianza del modelo en la transcripción.
logprobs solo funciona con response_format establecido json en y solo con los modelos gpt-4o-transcribe, gpt-4o-transcribe-diarize, gpt-4o-mini-transcribey gpt-4o-mini-transcribe-2025-12-15. |
No | |
| language | string | Idioma del audio de entrada. Proporcionar el idioma de entrada en formato ISO-639-1 (por ejemplo, en) mejorará la precisión y la latencia. |
No | |
| model | string | Modelo que se va a usar para esta solicitud de transcripción. | No | |
| prompt | string | Texto opcional para guiar el estilo del modelo o continuar con un segmento de audio anterior. El mensaje debe coincidir con el idioma de audio. | No | |
| formato_de_respuesta | object | No | ||
| stream | boolean | Si se establece en true, los datos de respuesta del modelo se transmitirán al cliente a medida que se generan mediante eventos enviados por el servidor. Nota: El streaming no se admite para el whisper-1 modelo y se omitirá. |
No | Falso |
| temperatura | número | Temperatura de muestreo, entre 0 y 1. Los valores más altos como 0,8 harán que la salida sea más aleatoria, mientras que los valores más bajos como 0,2 harán que sea más centrado y determinista. Si se establece en 0, el modelo usará la probabilidad de registro para aumentar automáticamente la temperatura hasta que se alcancen determinados umbrales. | No | 0 |
| timestamp_granularities[] | array | Granularidades de marca de tiempo que se van a rellenar para esta transcripción.
response_format debe establecerse verbose_json para usar granularidades de marca de tiempo. Se admiten o ambas opciones: word, o segment. Nota: No hay ninguna latencia adicional para las marcas de tiempo de segmento, pero la generación de marcas de tiempo de palabra incurre en una latencia adicional. |
No | ['segment'] |
Responses
Código de estado: 200
Descripción: la solicitud se ha realizado correctamente.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureAudioTranscriptionResponse | |
| text/plain | string |
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureErrorResponse |
Examples
Example
Obtiene texto transcrito y metadatos asociados de los datos de audio hablados proporcionados.
POST {endpoint}/openai/v1/audio/transcriptions?api-version=preview
{
"file": "<binary audio data>",
"model": "whisper-1",
"response_format": "text"
}
Respuestas: Código de estado: 200
{
"body": "plain text when requesting text, srt, or vtt"
}
Crear traducción
POST {endpoint}/openai/v1/audio/translations?api-version=preview
Obtiene el texto transcrito en inglés y los metadatos asociados de los datos de audio hablados proporcionados.
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Cuerpo de la solicitud
Tipo de contenido: varias partes/datos de formulario
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| archivo | string | Sí | ||
| filename | string | Nombre de archivo opcional o identificador descriptivo al que se va a asociar con los datos de audio. | No | |
| model | string | Modelo que se va a usar para esta solicitud de traducción. | No | |
| prompt | string | Texto opcional para guiar el estilo del modelo o continuar con un segmento de audio anterior. El mensaje debe estar en inglés. | No | |
| formato_de_respuesta | object | No | ||
| temperatura | número | Temperatura de muestreo, entre 0 y 1. Los valores más altos como 0,8 harán que la salida sea más aleatoria, mientras que los valores más bajos como 0,2 harán que sea más centrado y determinista. Si se establece en 0, el modelo usará la probabilidad de registro para aumentar automáticamente la temperatura hasta que se alcancen determinados umbrales. | No | 0 |
Responses
Código de estado: 200
Descripción: la solicitud se ha realizado correctamente.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureAudioTranslationResponse | |
| text/plain | string |
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureErrorResponse |
Examples
Example
Obtiene el texto transcrito en inglés y los metadatos asociados de los datos de audio hablados proporcionados.
POST {endpoint}/openai/v1/audio/translations?api-version=preview
{
"file": "<binary audio data>",
"model": "whisper-1",
"response_format": "text"
}
Respuestas: Código de estado: 200
{
"body": "plain text when requesting text, srt, or vtt"
}
Crear edición de imágenes
POST {endpoint}/openai/v1/images/edits?api-version=preview
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Cuerpo de la solicitud
Tipo de contenido: varias partes/datos de formulario
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| fondo | enum | Permite establecer transparencia para el fondo de las imágenes generadas. Este parámetro solo se admite para gpt-image-1 los modelos. Debe ser , transparentopaque o auto (valor predeterminado). Cuando auto se usa, el modelo determinará automáticamente el mejor fondo para la imagen.Si transparentes , el formato de salida debe admitir la transparencia, por lo que debe establecerse png en (valor predeterminado) o webp.Valores posibles: transparent, opaque, auto |
No | |
| imagen | string o array | Sí | ||
| máscara | string | No | ||
| model | string | Implementación del modelo que se va a usar para la operación de edición de imágenes. | Sí | |
| n | entero | Número de imágenes que se van a generar. Debe estar entre 1 y 10. | No | 1 |
| compresión_de_salida | entero | Nivel de compresión (0-100%) para las imágenes generadas. Este parámetro solo se admite para gpt-image-1los modelos de la serie -con formatos webp de salida o jpeg y el valor predeterminado es 100. |
No | 100 |
| formato_de_salida | enum | Formato en el que se devuelven las imágenes generadas. Este parámetro solo se admite para gpt-image-1los modelos de la serie -. Debe ser uno de png, jpego webp.El valor predeterminado es png.Valores posibles: png, jpeg, webp |
No | |
| prompt | string | Descripción de texto de las imágenes deseadas. La longitud máxima es de 1000 caracteres para dall-e-2, y 32000 caracteres para gpt-image-1los modelos de serie . |
Sí | |
| calidad | enum | Calidad de la imagen que se generará.
high, medium y low solo se admiten para gpt-image-1los modelos de la serie .
dall-e-2 solo admite standard calidad. El valor predeterminado es auto.Valores posibles: standard, low, medium, , high, auto |
No | |
| formato_de_respuesta | enum | Formato en el que se devuelven las imágenes generadas. Debe ser uno de url o b64_json. Las direcciones URL solo son válidas durante 60 minutos después de que se haya generado la imagen. Este parámetro solo se admite para dall-e-2, ya gpt-image-1que los modelos de serie siempre devolverán imágenes codificadas en base64.Valores posibles: url, b64_json |
No | |
| size | enum | Tamaño de las imágenes generadas. Debe ser uno de 1024x1024, 1536x1024 (horizontal), 1024x1536 (vertical) o auto (valor predeterminado) para gpt-image-1los modelos de la serie y uno de 256x256, 512x512o 1024x1024 para dall-e-2.Valores posibles: 256x256, 512x512, 1024x1024, 1536x1024, , 1024x1536, auto |
No | |
| user | string | Identificador único que representa al usuario final, que puede ayudar a OpenAI a supervisar y detectar abusos. | No |
Responses
Código de estado: 200
Descripción: la solicitud se ha realizado correctamente.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureImagesResponse |
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureErrorResponse |
Createimage
POST {endpoint}/openai/v1/images/generations?api-version=preview
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Cuerpo de la solicitud
Tipo-Contenido: application/json
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| fondo | enum | Permite establecer transparencia para el fondo de las imágenes generadas. Este parámetro solo se admite para gpt-image-1 los modelos. Debe ser , transparentopaque o auto (valor predeterminado). Cuando auto se usa, el modelo determinará automáticamente el mejor fondo para la imagen.Si transparentes , el formato de salida debe admitir la transparencia, por lo que debe establecerse png en (valor predeterminado) o webp.Valores posibles: transparent, opaque, auto |
No | |
| model | string | Implementación del modelo que se va a usar para la generación de imágenes. | Sí | |
| moderación | enum | Controle el nivel de moderación de contenido para las imágenes generadas por gpt-image-1modelos de serie. Debe ser low para un filtrado menos restrictivo o auto (valor predeterminado).Valores posibles: low, auto |
No | |
| n | entero | Número de imágenes que se van a generar. Debe estar entre 1 y 10. Para dall-e-3, solo n=1 se admite. |
No | 1 |
| compresión_de_salida | entero | Nivel de compresión (0-100%) para las imágenes generadas. Este parámetro solo se admite para gpt-image-1los modelos de la serie -con formatos webp de salida o jpeg y el valor predeterminado es 100. |
No | 100 |
| formato_de_salida | enum | Formato en el que se devuelven las imágenes generadas. Este parámetro solo se admite para gpt-image-1los modelos de la serie -. Debe ser uno de png, jpego webp.Valores posibles: png, jpeg, webp |
No | |
| prompt | string | Descripción de texto de las imágenes deseadas. La longitud máxima es de 32000 caracteres para gpt-image-1los modelos de series , 1000 caracteres para dall-e-2 y 4000 caracteres para dall-e-3. |
Sí | |
| calidad | enum | Calidad de la imagen que se generará. - auto (valor predeterminado) seleccionará automáticamente la mejor calidad para el modelo especificado.- high, medium y low son compatibles con gpt-image-1los modelos de la serie .- hd y standard son compatibles con dall-e-3.- standard es la única opción para dall-e-2.Valores posibles: standard, hd, low, medium, , high, auto |
No | |
| formato_de_respuesta | enum | Formato en el que se devuelven las imágenes generadas con dall-e-2 y dall-e-3 . Debe ser uno de url o b64_json. Las direcciones URL solo son válidas durante 60 minutos después de que se haya generado la imagen. Este parámetro no se admite para gpt-image-1los modelos de la serie -que siempre devolverán imágenes codificadas en base64.Valores posibles: url, b64_json |
No | |
| size | enum | Tamaño de las imágenes generadas. Debe ser uno de 1024x1024, 1536x1024 (horizontal), 1024x1536 (vertical) o auto (valor predeterminado) para gpt-image-1los modelos de serie , uno de 256x256, 512x512o 1024x1024 para dall-e-2, y uno de 1024x1024, 1792x1024o 1024x1792 para dall-e-3.Valores posibles: auto, 1024x1024, 1536x1024, 1024x1536, 256x256, 512x512, , , 1792x10241024x1792 |
No | |
| estilo | enum | Estilo de las imágenes generadas. Este parámetro solo se admite para dall-e-3. Debe ser uno de vivid o natural. Vívido hace que el modelo se inclina hacia la generación de imágenes hiper-reales y dramáticas. Natural hace que el modelo produzca imágenes más naturales y menos hiper-reales.Valores posibles: vivid, natural |
No | |
| user | string | Identificador único que representa al usuario final, que puede ayudar a OpenAI a supervisar y detectar abusos. | No |
Responses
Código de estado: 200
Descripción: la solicitud se ha realizado correctamente.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureImagesResponse |
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureErrorResponse |
Examples
Example
Crea imágenes dadas una solicitud.
POST {endpoint}/openai/v1/images/generations?api-version=preview
{
"model": "dall-e-3",
"prompt": "In the style of WordArt, Microsoft Clippy wearing a cowboy hat.",
"n": 1,
"style": "natural",
"quality": "standard"
}
Respuestas: Código de estado: 200
{
"body": {
"created": 1698342300,
"data": [
{
"revised_prompt": "A vivid, natural representation of Microsoft Clippy wearing a cowboy hat.",
"prompt_filter_results": {
"sexual": {
"severity": "safe",
"filtered": false
},
"violence": {
"severity": "safe",
"filtered": false
},
"hate": {
"severity": "safe",
"filtered": false
},
"self_harm": {
"severity": "safe",
"filtered": false
},
"profanity": {
"detected": false,
"filtered": false
},
"custom_blocklists": {
"filtered": false,
"details": []
}
},
"url": "https://dalletipusw2.blob.core.windows.net/private/images/e5451cc6-b1ad-4747-bd46-b89a3a3b8bc3/generated_00.png?se=2023-10-27T17%3A45%3A09Z&...",
"content_filter_results": {
"sexual": {
"severity": "safe",
"filtered": false
},
"violence": {
"severity": "safe",
"filtered": false
},
"hate": {
"severity": "safe",
"filtered": false
},
"self_harm": {
"severity": "safe",
"filtered": false
}
}
}
]
}
}
Trabajos de generación de vídeo: crear
POST {endpoint}/openai/v1/video/generations/jobs?api-version=preview
Crea un nuevo trabajo de generación de vídeos.
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Cuerpo de la solicitud
Tipo-Contenido: application/json
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| height | entero | Alto del vídeo. Se admiten las siguientes dimensiones: 480x480, 854x480, 720x720, 1280x720, 1080x1080 y 1920x1080 en orientación horizontal y vertical. | Sí | |
| model | string | Nombre de la implementación que se va a usar para esta solicitud. | Sí | |
| n_seconds | entero | Duración del trabajo de generación de vídeo. Debe estar entre 1 y 20 segundos. | No | 5 |
| n_variants | entero | Número de vídeos que se van a crear como variantes para este trabajo. Debe estar entre 1 y 5. Las dimensiones más pequeñas permiten más variantes. | No | 1 |
| prompt | string | Solicitud de este trabajo de generación de vídeo. | Sí | |
| width | entero | Ancho del vídeo. Se admiten las siguientes dimensiones: 480x480, 854x480, 720x720, 1280x720, 1080x1080 y 1920x1080 en orientación horizontal y vertical. | Sí |
Cuerpo de la solicitud
Tipo de contenido: varias partes/datos de formulario
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| archivos | array | Sí | ||
| height | entero | Alto del vídeo. Se admiten las siguientes dimensiones: 480x480, 854x480, 720x720, 1280x720, 1080x1080 y 1920x1080 en orientación horizontal y vertical. | Sí | |
| inpaint_items | array | Elementos opcionales de inpainting para este trabajo de generación de vídeo. | No | |
| model | string | Nombre de la implementación que se va a usar para esta solicitud. | Sí | |
| n_seconds | entero | Duración del trabajo de generación de vídeo. Debe estar entre 1 y 20 segundos. | No | 5 |
| n_variants | entero | Número de vídeos que se van a crear como variantes para este trabajo. Debe estar entre 1 y 5. Las dimensiones más pequeñas permiten más variantes. | No | 1 |
| prompt | string | Solicitud de este trabajo de generación de vídeo. | Sí | |
| width | entero | Ancho del vídeo. Se admiten las siguientes dimensiones: 480x480, 854x480, 720x720, 1280x720, 1080x1080 y 1920x1080 en orientación horizontal y vertical. | Sí |
Responses
Código de estado: 200
Descripción: la solicitud se ha realizado correctamente.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | VideoGenerationJob |
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Examples
Archivo de ejemplo no encontrado: ./examples/create_video_generation_job_simple.json
Trabajos de generación de vídeo: lista
GET {endpoint}/openai/v1/video/generations/jobs?api-version=preview
Enumera los trabajos de generación de vídeo.
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
|
| before | consulta | No | string | |
| después | consulta | No | string | |
| limit | consulta | Sí | entero | |
| statuses | consulta | No | array |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Responses
Código de estado: 200
Descripción: la solicitud se ha realizado correctamente.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | VideoGenerationJobList |
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Examples
Archivo de ejemplo no encontrado: ./examples/get_video_generation_job_list.json
Trabajos de generación de vídeo: Obtener
GET {endpoint}/openai/v1/video/generations/jobs/{job-id}?api-version=preview
Recupera las propiedades de un trabajo de generación de vídeo.
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
|
| job-id | ruta | Sí | string | Identificador del trabajo de generación de vídeo que se va a usar para la solicitud openAI de Azure. |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Responses
Código de estado: 200
Descripción: la solicitud se ha realizado correctamente.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | VideoGenerationJob |
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Examples
Archivo de ejemplo no encontrado: ./examples/get_video_generation_job.json
Trabajos de generación de vídeo: eliminar
DELETE {endpoint}/openai/v1/video/generations/jobs/{job-id}?api-version=preview
Elimina un trabajo de generación de vídeo.
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
|
| job-id | ruta | Sí | string | Identificador del trabajo de generación de vídeo que se va a usar para la solicitud openAI de Azure. |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Responses
Código de estado: 204
Descripción: no hay contenido que enviar para esta solicitud, pero los encabezados pueden ser útiles.
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Generaciones de vídeo: Obtener
GET {endpoint}/openai/v1/video/generations/{generation-id}?api-version=preview
Recupera una generación de vídeo por identificador.
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
|
| generation-id | ruta | Sí | string | Identificador de la generación de vídeo que se va a usar para la solicitud de OpenAI de Azure. |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Responses
Código de estado: 200
Descripción: la solicitud se ha realizado correctamente.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | VideoGeneration |
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Examples
Archivo de ejemplo no encontrado: ./examples/get_video_generation.json
Generaciones de vídeo: recuperación de miniaturas
GET {endpoint}/openai/v1/video/generations/{generation-id}/content/thumbnail?api-version=preview
Recupera una miniatura del contenido de vídeo generado.
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
|
| generation-id | ruta | Sí | string | Identificador de la generación de vídeo que se va a usar para la solicitud de OpenAI de Azure. |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Responses
Código de estado: 200
Descripción: la solicitud se ha realizado correctamente.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| image/jpg | string |
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Generaciones de vídeo: recuperación del contenido de vídeo
GET {endpoint}/openai/v1/video/generations/{generation-id}/content/video?api-version=preview
Recupera el contenido de vídeo generado.
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
|
| generation-id | ruta | Sí | string | Identificador de la generación de vídeo que se va a usar para la solicitud de OpenAI de Azure. |
| calidad | consulta | No |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Responses
Código de estado: 200
Descripción: la solicitud se ha realizado correctamente.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| video/mp4 | string |
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Generaciones de vídeo: solo recuperar encabezados de vídeocontent
HEAD {endpoint}/openai/v1/video/generations/{generation-id}/content/video?api-version=preview
Recupera encabezados para el contenido de vídeo generado.
Parámetros de URI
| Nombre | En | Obligatorio | Tipo | Descripción |
|---|---|---|---|---|
| endpoint | ruta | Sí | string url |
Se admiten Azure puntos de conexión de OpenAI (protocolo y nombre de host, por ejemplo: https://aoairesource.openai.azure.com. Reemplace "aoairesource" por el nombre del recurso de OpenAI de Azure). https://{your-resource-name}.openai.azure.com |
| versión de la API | consulta | No | La versión explícita de foundry Models API que se va a usar para esta solicitud.v1 si no se especifica lo contrario. |
|
| generation-id | ruta | Sí | string | Identificador de la generación de vídeo que se va a usar para la solicitud de OpenAI de Azure. |
| calidad | consulta | No |
Encabezado de solicitud
Use la autenticación basada en tokens o la clave de API. La autenticación con autenticación basada en tokens se recomienda y es más segura.
| Nombre | Obligatorio | Tipo | Descripción |
|---|---|---|---|
| Autorización | Cierto | string |
Ejemplo:Authorization: Bearer {Azure_OpenAI_Auth_Token}Para generar un token de autenticación mediante CLI de Azure: az account get-access-token --resource https://cognitiveservices.azure.comTipo: oauth2 Dirección URL de autorización: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeámbito: https://ai.azure.com/.default |
| clave de API | Cierto | string | Proporcione Azure clave de API de OpenAI aquí |
Responses
Código de estado: 200
Descripción: la solicitud se ha realizado correctamente.
Código de estado: valor predeterminado
Descripción: una respuesta de error inesperada.
| Tipo de contenido | Tipo | Descripción |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Componentes
Para conocer las definiciones de esquema usadas por chat, finalizaciones, incrustaciones, respuestas y otras operaciones de texto, consulte la referencia de la API rest de OpenAI de Azure. Los siguientes esquemas admiten las operaciones de imagen, audio y vídeo en esta página.
AzureAudioTranscriptionResponse
Información de resultados de una operación que transcribió el audio hablado en texto escrito.
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| duración | número | Duración total del audio procesado para generar información de transcripción complementaria. | No | |
| language | string | Idioma hablado que se detectó en los datos de audio transcritos. Esto se expresa como un código de lenguaje ISO-639-1 de dos letras, como "en" o "fr". |
No | |
| segmentos | array | Colección de información sobre el tiempo, las probabilidades y otros detalles de cada segmento de audio procesado. | No | |
| tarea | object | Define los posibles descriptores para las respuestas de operación de audio disponibles. | No | |
| Mensaje de texto | string | Texto transcrito para los datos de audio proporcionados. | Sí | |
| words | array | Colección de información sobre el tiempo de cada palabra procesada. | No |
AzureAudioTranslationResponse
Información de resultados de una operación que traducía el audio hablado en texto escrito.
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| duración | número | Duración total del audio procesado para generar información de traducción complementaria. | No | |
| language | string | Idioma hablado que se detectó en los datos de audio traducidos. Esto se expresa como un código de lenguaje ISO-639-1 de dos letras, como "en" o "fr". |
No | |
| segmentos | array | Colección de información sobre el tiempo, las probabilidades y otros detalles de cada segmento de audio procesado. | No | |
| tarea | object | Define los posibles descriptores para las respuestas de operación de audio disponibles. | No | |
| Mensaje de texto | string | Texto traducido para los datos de audio proporcionados. | Sí |
AzureErrorResponse
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| error | object | Detalles del error. | No | |
| └─ código | string | Identificador distinto generado por la máquina para el error. | No | |
| └" inner_error | No | |||
| └─ Mensaje | string | Mensaje legible asociado al error. | No | |
| └— param | string | Si procede, el parámetro de entrada de solicitud asociado al error | No | |
| └─ Tipo | enum | El tipo de objeto, siempre 'error'. Valores posibles: error |
No |
AzureImagesResponse
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| fondo | enum | GPT-image-1 solo: el parámetro de fondo usado para la generación de imágenes.
transparentO opaque .Valores posibles: transparent, opaque |
No | |
| creado | entero | Marca de tiempo de Unix (en segundos) de cuando se creó la imagen. | Sí | |
| datos | array | No | ||
| formato_de_salida | enum | Formato de salida de la generación de imágenes. Ya sea png, webpo jpeg.Valores posibles: png, webp, jpeg |
No | |
| calidad | enum | Calidad de la imagen generada. Ya sea low, mediumo high.Valores posibles: low, medium, high |
No | |
| size | enum | Tamaño de la imagen generada. Ya sea 1024x1024, 1024x1536o 1536x1024.Valores posibles: 1024x1024, 1024x1536, 1536x1024 |
No | |
| uso | object | Solo para gpt-image-1los modelos de la serie -, la información de uso del token para la generación de imágenes. |
No | |
| └" input_tokens | entero | Número de tokens (imágenes y texto) en el símbolo del sistema de entrada. | No | |
| └─ detalles_de_tokens_de_entrada | object | La información detallada de los tokens de entrada para la generación de imágenes. | No | |
| └" image_tokens | entero | Número de tokens de imagen en el símbolo del sistema de entrada. | No | |
| └" text_tokens | entero | Número de tokens de texto en el símbolo del sistema de entrada. | No | |
| └" output_tokens | entero | Número de tokens de imagen en la imagen de salida. | No | |
| └" total_tokens | entero | Número total de tokens (imágenes y texto) usados para la generación de imágenes. | No |
AzureOpenAIVideoGenerationErrorResponse
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| código | string | Identificador distinto generado por la máquina para el error. | No | |
| inner_error | object | Si procede, un error ascendente que originó este error. | No | |
| └─ código | enum | Código asociado al error interno. Valores posibles: ResponsibleAIPolicyViolation |
No | |
| └─ detalles_del_error | Detalles del resultado del filtro de contenido asociados al error interno. | No | ||
| └" revised_prompt | string | Si procede, la solicitud modificada usada para la generación. | No | |
| Mensaje | string | Mensaje legible asociado al error. | No | |
| param | string | Si procede, el parámetro de entrada de solicitud asociado al error | No | |
| type | string | Si procede, el número de línea de entrada asociado al error. | No |
VideoGeneration
Resultado de la generación de vídeos.
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| fecha_de_creación | entero | Hora a la que se creó la generación de vídeos. | Sí | |
| height | entero | Alto del vídeo. | Sí | |
| id | string | Identificador de la generación de vídeo. | Sí | |
| job_id | string | El identificador del trabajo de generación de vídeos para este vídeo. | Sí | |
| n_seconds | entero | Duración de la generación de vídeo. | Sí | |
| object | enum | Valores posibles: video.generation |
Sí | |
| prompt | string | Solicitud de esta generación de vídeo. | Sí | |
| width | entero | Ancho del vídeo. | Sí |
VideoGenerationJob
Un trabajo de generación de vídeos.
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| fecha_de_creación | entero | Hora a la que se creó el trabajo. | Sí | |
| expires_at | entero | Hora a la que el trabajo se elimina automáticamente del servicio. El contenido de vídeo y los metadatos del trabajo deben almacenarse antes de esta fecha para evitar la pérdida de datos. | No | |
| failure_reason | string (consulte los modelos válidos a continuación) | No | ||
| finished_at | entero | Hora en la que el trabajo finalizó con todas las generaciones de vídeos. | No | |
| generaciones | array | Vídeos generados para este trabajo. El número depende del n_variants especificado y del éxito de creación de las generaciones. | No | |
| height | entero | Alto del vídeo. | Sí | |
| id | string | Identificador del trabajo. | Sí | |
| inpaint_items | array | Elementos opcionales de inpainting para este trabajo de generación de vídeo. | No | |
| model | string | Nombre de la implementación que se va a usar para este trabajo de generación de vídeos. | Sí | |
| n_seconds | entero | Duración del trabajo de generación de vídeo. | Sí | |
| n_variants | entero | Número de vídeos que se van a crear como variantes para este trabajo de generación de vídeos. | Sí | |
| object | enum | Valores posibles: video.generation.job |
Sí | |
| prompt | string | Solicitud de este trabajo de generación de vídeo. | Sí | |
| estado | object | Estado de un trabajo de generación de vídeo. | Sí | |
| width | entero | Alto del vídeo. | Sí |
VideoGenerationJobList
Lista de trabajos de generación de vídeos.
| Nombre | Tipo | Descripción | Obligatorio | Predeterminado |
|---|---|---|---|---|
| datos | array | Lista de trabajos de generación de vídeo. | Sí | |
| first_id | string | Identificador del primer trabajo de la página actual, si está disponible. | No | |
| has_more | boolean | Marca que indica si hay más trabajos disponibles después de la lista. | Sí | |
| last_id | string | Identificador del último trabajo de la página actual, si está disponible. | No | |
| object | enum | Valores posibles: list |
Sí |
Pasos siguientes
Obtenga información sobre los modelos y la optimización con la API REST. Obtenga más información sobre los modelos underlying que potencian Azure OpenAI.